@@ -2,6 +2,7 @@
 
 import argparse
 import bz2
+import csv
 import datetime
 import decimal
 import gzip
@@ -230,7 +231,7 @@ class CSVKitUtility:
                      '1-based numbering.')
 
         self.argparser.add_argument(
-            '-V', '--version', action='version', version='%(prog)s 1.3.0',
+            '-V', '--version', action='version', version='%(prog)s 1.4.0',
             help='Display version information and exit.')
 
     def _open_input_file(self, path, opened=False):
@@ -264,12 +265,16 @@ class CSVKitUtility:
         """
         kwargs = {}
 
+        field_size_limit = getattr(self.args, 'field_size_limit')
+        if field_size_limit is not None:
+            csv.field_size_limit(field_size_limit)
+
         if self.args.tabs:
             kwargs['delimiter'] = '\t'
         elif self.args.delimiter:
             kwargs['delimiter'] = self.args.delimiter
 
-        for arg in ('quotechar', 'quoting', 'doublequote', 'escapechar', 'field_size_limit', 'skipinitialspace'):
+        for arg in ('quotechar', 'quoting', 'doublequote', 'escapechar', 'skipinitialspace'):
             value = getattr(self.args, arg)
             if value is not None:
                 kwargs[arg] = value
